.. _reference_tensor_sorting:
.. currentmodule:: aesara.tensor


Sorting, searching and counting
===============================

.. autosummary::
   :toctree: _autosummary

   sort
   argsort
   argmax
   argmin
   nonzero
   flatnonzero
   searchsorted
   where
